<?php
/*
Plugin Name: Random Number Generator
Plugin URI: http://blogs.wittwer.fr/whiler/
Description: Generates a random number (for instance, useful to avoid browsers links cache)
Version: 0.0.1
Author: Whiler
Author URI: http://william.wittwer.fr/
*/

// Interdit les appels directs  la page
if (!function_exists("get_option")) {
  echo 'SIG'; // Silence is golden
  die;
}

// Cl utilise pour le tag  dtecter dans les articles/pages/commentaires [random-number] (not a constant... users can maybe update it in a future release)
$random_number_generator_key = 'random-number';

// Charge le fichier de traduction s'il existe
load_plugin_textdomain('random_number_generator', '', '/random_number_generator/languages');

/**
 * Fonction qui rcupre et valide les paramtres avant de les renvoyer par rfrence
 * @param integer &$random_number_generator_from   Valeur minimale
 * @param integer &$random_number_generator_to     Valeur maximale
 * @param string  &$random_number_generator_format Format utilis pour l'affichage
 */
function get_data(&$random_number_generator_from, &$random_number_generator_to, &$random_number_generator_format) {
	// Rcupration des paramtres depuis les options de WP
	$random_number_generator_from   = get_option('random_number_generator_from');
	$random_number_generator_to     = get_option('random_number_generator_to');
	$random_number_generator_format = get_option('random_number_generator_format');
	// Validation de la cohrence des valeurs
	if (($random_number_generator_from == $random_number_generator_to) || ($random_number_generator_from > $random_number_generator_to)) {
		$random_number_generator_from = 0;
		$random_number_generator_to   = mt_getrandmax();
	}
	if (($random_number_generator_format == null) || (trim($random_number_generator_format) == '')) {
		$random_number_generator_format = "%x";
	}
}

/**
 * Fonction appele  l'activation de l'extension
 */
function random_number_generator_install() {
	// Ajout des valeurs par dfaut
  add_option('random_number_generator_from', 0);
  add_option('random_number_generator_to', mt_getrandmax());
  add_option('random_number_generator_format', "%x");
}

/**
 * Fonction affichant la page de rglage des options
 */
function random_number_generator_optionsPage() {
	get_data($random_number_generator_from, $random_number_generator_to, $random_number_generator_format);
?>
<div class="wrap">
 	<h2><?php /*Tr.: Settings page title / %s: Plugin name*/ printf(str_replace('%s', '<strong>%s</strong>', __('%s Options', 'random_number_generator')), 'Random Number Generator'); ?></h2>
	<form method="post" action="options.php">
		<?php wp_nonce_field('update-options'); ?>
		<table class="form-table">
			<tr valign="top">
				<th  colspan="2" scope="row">
					<?php global $random_number_generator_key; printf(__('Simply replace the tag %s by a random number.', 'random_number_generator'), "<code>[$random_number_generator_key]</code>"); ?><br/>
					<span class="description"><?php printf(__('Used to avoid browsers cache by inserting a random number. For instance, %1$s generates %2$s.', 'random_number_generator'), "<code>&lt;a href=\"http://".__('my_url', 'random_number_generator')."?[$random_number_generator_key]\"&gt;</code>", "<code>&lt;a href=\"http://".__('my_url', 'random_number_generator')."?".random_number_generator_shortcode_handler()."\"&gt;</code>"); ?></span>
				</th>
			</tr>
			<tr valign="top">
				<th scope="row" style="text-align: right;">
					<?php _e('From:', 'random_number_generator') ?>
				</th>
				<td>
					<input type="text" name="random_number_generator_from" value="<?php echo $random_number_generator_from; ?>" /> 
					<a class="button" title="<?php _e('Dispay more details', 'random_number_generator') ?>" onclick="javascript:switchVisibility('random_number_generator_from_help');"><?php /*Tr.: Button caption for help*/ _e('?', 'random_number_generator'); ?></a> 
					<span id="random_number_generator_from_help" style="text-align: left; display: none;"> <?php printf(__('Lowest integer value to be returned (default: <code>%d</code>).', 'random_number_generator'), 0); ?></span>
				</td>
			</tr>
			<tr valign="top">
				<th scope="row" style="text-align: right;">
					<?php _e('To:', 'random_number_generator'); ?>
				</th>
				<td>
					<input type="text" name="random_number_generator_to" value="<?php echo $random_number_generator_to; ?>" /> 
					<a class="button" title="<?php _e('Dispay more details', 'random_number_generator') ?>" onclick="javascript:switchVisibility('random_number_generator_to_help');"><?php _e('?', 'random_number_generator'); ?></a> 
					<span id="random_number_generator_to_help" style="text-align: left; display: none;"> <?php printf(__('Highest integer value to be returned (default: <code>%d</code>).', 'random_number_generator'), mt_getrandmax()); ?></span>
				</td>
			</tr>
			<tr valign="top">
				<th scope="row" style="text-align: right;">
					<?php _e('Format:', 'random_number_generator') ?>
				</th>
				<td>
					<input type="text" name="random_number_generator_format" value="<?php echo $random_number_generator_format; ?>" /> 
					<a class="button" title="<?php _e('Dispay more details', 'random_number_generator') ?>" onclick="javascript:switchVisibility('random_number_generator_format_help');"><?php _e('?', 'random_number_generator'); ?></a> 
					<span id="random_number_generator_format_help" style="text-align: left; display: none;"> <?php printf(__('Random number produced according to the formatting string above (default: <code>%s</code>).', 'random_number_generator'), '%x'); ?><br/>
					<?php printf(__('See %s documentation for a description of format.', 'random_number_generator'), '<a href="'.__('http://www.php.net/manual/en/function.sprintf.php', 'random_number_generator').'" target"_blank" title="'.__('Visit PHP: sprintf - Manual page', 'random_number_generator').'">sprintf()</a>'); ?></span>
				</td>
			</tr>
		</table>
		<input type="hidden" name="action" value="update" />
		<input type="hidden" name="page_options" value="random_number_generator_from,random_number_generator_to,random_number_generator_format" />
		<?php settings_fields( 'random_number_generator' ); ?>
		<p class="submit">
			<input type="submit" class="button-primary" value="<?php _e('Save Changes', 'random_number_generator') ?>" />
		</p>
	</form>
</div>
<?php
}

/**
 * Fonction ajoutant un lien pour la page des options dans la liste des extensions
 * @param string $links Lien en cours
 * @param string $file Extension en cours
 * @return HTML
 */
function random_number_generator_plugin_action_links($links, $file) {
  if ($file == plugin_basename(dirname(__FILE__).'/random_number_generator.php')){
  	//Le commentaire ci-dessous est extrait par Poedit pour tre mis dans les commentaires afin d'aider  la traduction
  	//Tr.: Below the plugin name, in the plugin page
	  $settings_link = "<a href='options-general.php?page=random_number_generator/random_number_generator.php'>".__('Settings','random_number_generator')."</a>";
	  array_unshift( $links, $settings_link );
  }
  return $links;
}

/**
 * Fonction ajoutant les scripts ncessaires dans les rglages de l'extension
 */
function random_number_generator_scripts() {
  wp_enqueue_script('random_number_generator_script1', WP_PLUGIN_URL.'/'.str_replace(".php",".js",plugin_basename(__FILE__)));
//  wp_enqueue_script('random_number_generator_script2', 'my2ndScript', array('jquery', 'jquery-ui-tabs'));
}

/**
 * Fonction ajoutant un lien dans le menu Rglages pour la page des options de l'extension
 */
function random_number_generator_settings_menu() {
  if (function_exists('add_submenu_page')) {
  	//Tr.: Settings menu plugin caption
    $random_number_generator_settings_page = add_submenu_page('options-general.php',__('Rand#Gen.','random_number_generator'), __('Rand#Gen.','random_number_generator'), "install_plugins", __FILE__, 'random_number_generator_optionsPage');
    // Ajoute les scripts JavaScript utiliss par les pages d'administration de l'extension
    add_action( "admin_print_scripts-$random_number_generator_settings_page", 'random_number_generator_scripts' );
	}
}

/**
 * Fonction qui rpertorie les paramtres de l'extension et les mthodes de callback(validation)
 */
function register_random_number_generator_settings() { // whitelist options
  register_setting( 'random_number_generator', 'random_number_generator_from', 'intval' ); // Valeur entire uniquement
  register_setting( 'random_number_generator', 'random_number_generator_to', 'intval' );
  register_setting( 'random_number_generator', 'random_number_generator_format', 'wp_filter_nohtml_kses' ); // HTML interdit
}


/**
 * Fonction renvoyant un chiffre alatoire
 * @return HTML
 */
function random_number_generator_shortcode_handler() {
	// $atts    ::= array of attributes
	// $content ::= text within enclosing form of shortcode element
	// $code    ::= the shortcode found, when == callback name
	// examples: [my-shortcode]
	//           [my-shortcode/]
	//           [my-shortcode foo='bar']
	//           [my-shortcode foo='bar'/]
	//           [my-shortcode]content[/my-shortcode]
	//           [my-shortcode foo='bar']content[/my-shortcode]
	
	// Rcupre les diffrentes options
	get_data($random_number_generator_from, $random_number_generator_to, $random_number_generator_format);
	// Gnration alatoire
	mt_srand();
	// Renvoie un nombre alatoire
	return sprintf($random_number_generator_format, mt_rand($random_number_generator_from, $random_number_generator_to));
}

// Ajout du hook pour dtecter/remplacer le mot-cl lorsqu'il est utilis
add_shortcode($random_number_generator_key, 'random_number_generator_shortcode_handler');

// Si on est administrateur
if (is_admin()) {
	// Mthode  appeler lors de l'activation de l'extension
  register_activation_hook(__FILE__, "random_number_generator_install");
  // Mthode  appeler lors de la gnration du menu d'admin
  add_action('admin_menu', 'random_number_generator_settings_menu');
  // Mthode  appeler lors de l'accs  l'administration
  add_action('admin_init', 'register_random_number_generator_settings' );
  // Mthode  appeler lors de l'affichage des liens d'action sur la page des extensions installes
	add_filter('plugin_action_links', 'random_number_generator_plugin_action_links', 10, 2);
}

?>